[Skiboot] [PATCH v2 5/5] platform/astbmc: Only send external IRQs to OPAL if there is a handler

Oliver O'Halloran oohall at gmail.com
Thu Sep 5 13:08:45 AEST 2019


If the platform hasn't defined an external IRQ handler then we should
leave it directed at the OS. The OS can mask it if it wants to.

Signed-off-by: Oliver O'Halloran <oohall at gmail.com>
---
 platforms/astbmc/common.c | 5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)

diff --git a/platforms/astbmc/common.c b/platforms/astbmc/common.c
index 85043f3b91e7..1f8a3f82c358 100644
--- a/platforms/astbmc/common.c
+++ b/platforms/astbmc/common.c
@@ -465,8 +465,9 @@ void astbmc_early_init(void)
 	/* Hostboot forgets to populate the PSI BAR */
 	astbmc_fixup_psi_bar();
 
-	/* Send external interrupts to me */
-	psi_set_external_irq_policy(EXTERNAL_IRQ_POLICY_SKIBOOT);
+	/* Send external interrupts to me if the platform can handle them */
+	if (platform.external_irq)
+		psi_set_external_irq_policy(EXTERNAL_IRQ_POLICY_SKIBOOT);
 
 	if (ast_sio_init()) {
 		if (ast_io_init()) {
-- 
2.21.0



More information about the Skiboot mailing list